summaryrefslogtreecommitdiff
path: root/nuttx
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-03-20 03:39:17 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2013-03-20 03:39:17 +0000
commit14a689eafb060d06234357c70a29630d9bfd502f (patch)
tree6b70029a65290dfa58f0a092af89846dca758dbd /nuttx
parent8a062dae26f2825901035d88dc9cd907f052bade (diff)
downloadpx4-nuttx-14a689eafb060d06234357c70a29630d9bfd502f.tar.gz
px4-nuttx-14a689eafb060d06234357c70a29630d9bfd502f.tar.bz2
px4-nuttx-14a689eafb060d06234357c70a29630d9bfd502f.zip
Fix various typos assocated with LM4F
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@5763 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx')
-rw-r--r--nuttx/arch/arm/src/lm/lm_ethernet.c6
-rw-r--r--nuttx/configs/lm4f120-launchpad/README.txt5
-rw-r--r--nuttx/configs/lm4f120-launchpad/include/board.h9
-rw-r--r--nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c5
-rw-r--r--nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h7
5 files changed, 19 insertions, 13 deletions
diff --git a/nuttx/configs/lm4f120-launchpad/README.txt b/nuttx/configs/lm4f120-launchpad/README.txt
index ac7105fd2..e998ef3b7 100644
--- a/nuttx/configs/lm4f120-launchpad/README.txt
+++ b/nuttx/configs/lm4f120-launchpad/README.txt
@@ -194,6 +194,9 @@ Using OpenOCD and GDB with an FT2232 JTAG emulator
The relative path to the oocd.sh script is configs/lm4f120-launchpad/tools,
but that should have been added to your PATH variable when you sourced
the setenv.sh script.
+
+ Note that OpenOCD needs to be run with administrator privileges in
+ some environments (sudo).
Connecting GDB
@@ -432,7 +435,7 @@ NXFLAT Toolchain
LEDs
^^^^
- The LM32F120 has a single RGB LED. If CONFIG_ARCH_LEDS is defined, then
+ The LM4F120 has a single RGB LED. If CONFIG_ARCH_LEDS is defined, then
support for the LaunchPad LEDs will be included in the build. See:
- configs/lm4f120-launchpad/include/board.h - Defines LED constants, types and
diff --git a/nuttx/configs/lm4f120-launchpad/include/board.h b/nuttx/configs/lm4f120-launchpad/include/board.h
index 1e7d0ffcd..aa1d93ea0 100644
--- a/nuttx/configs/lm4f120-launchpad/include/board.h
+++ b/nuttx/configs/lm4f120-launchpad/include/board.h
@@ -53,7 +53,7 @@
* 32.768kHz connected to XOSC0/1 (pins 34/36)
*/
-#define SYSCON_RCC_XTAL SYSCON_RCC_XTAL16000KHZ /* On-board crystall is 16 MHz */
+#define SYSCON_RCC_XTAL SYSCON_RCC_XTAL16000KHZ /* On-board crystal is 16 MHz */
#define XTAL_FREQUENCY 16000000
/* Oscillator source is the main oscillator */
@@ -89,8 +89,9 @@
#define LM_RCC2_VALUE (SYSCON_RCC2_OSCSRC | SYSCON_RCC2_SYSDIV(LM_SYSDIV) | SYSCON_RCC2_DIV400)
/* LED definitions ******************************************************************/
-/* The LM32F120 has a single RGB LED. There is only one visible LED which will vary
- * in color. But, from the standpoint of the firmware, this appears as three LEDs:
+/* The LM4F120 LaunchPad has a single RGB LED. There is only one visible LED which
+ * will vary in color. But, from the standpoint of the firmware, this appears as
+ * three LEDs:
*
* BOARD_LED_R -- Connected to PF1
* BOARD_LED_G -- Connected to PF3
@@ -144,7 +145,7 @@
#define LED_PANIC 4 /* ON OFF OFF (flashing 2Hz) */
/* LED definitions ******************************************************************/
-/* The LM32F120 has a two buttons:
+/* The LM4F120 LaunchPad has a two buttons:
*
* BOARD_SW1 -- Connected to PF4
* BOARD_SW2 -- Connected to PF0
diff --git a/nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c b/nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c
index 9b26b9536..8cd548f94 100644
--- a/nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c
+++ b/nuttx/configs/lm4f120-launchpad/src/lm4f_autoleds.c
@@ -54,8 +54,9 @@
/****************************************************************************
* Definitions
****************************************************************************/
-/* The LM32F120 has a single RGB LED. There is only one visible LED which will vary
- * in color. But, from the standpoint of the firmware, this appears as three LEDs:
+/* The LM4F120 LaunchPad has a single RGB LED. There is only one visible LED
+ * which will vary in color. But, from the standpoint of the firmware, this
+ * appears as three LEDs:
*
* BOARD_LED_R -- Connected to PF1
* BOARD_LED_G -- Connected to PF3
diff --git a/nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h b/nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h
index 95dfc052a..b6f064b24 100644
--- a/nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h
+++ b/nuttx/configs/lm4f120-launchpad/src/lmf4120-launchpad.h
@@ -67,8 +67,9 @@
#endif
/* LM4F LaunchPad *******************************************************************/
-/* The LM32F120 has a single RGB LED. There is only one visible LED which will vary
- * in color. But, from the standpoint of the firmware, this appears as three LEDs:
+/* The LM4F120 LaunchPad has a single RGB LED. There is only one visible LED which
+ * will vary in color. But, from the standpoint of the firmware, this appears as
+ * three LEDs:
*
* BOARD_LED_R -- Connected to PF1
* BOARD_LED_G -- Connected to PF3
@@ -113,7 +114,7 @@
#define GPIO_LED_G (GPIO_FUNC_OUTPUT | GPIO_VALUE_ONE | GPIO_PORTF | GPIO_PIN_3)
#define GPIO_LED_B (GPIO_FUNC_OUTPUT | GPIO_VALUE_ONE | GPIO_PORTF | GPIO_PIN_2)
-/* The LM32F120 has a two buttons:
+/* The LM4F120 LaunchPad has a two buttons:
*
* BOARD_SW1 -- Connected to PF4
* BOARD_SW2 -- Connected to PF0
diff --git a/nuttx/arch/arm/src/lm/lm_ethernet.c b/nuttx/arch/arm/src/lm/lm_ethernet.c
index 861d64d95..88cc164a7 100644
--- a/nuttx/arch/arm/src/lm/lm_ethernet.c
+++ b/nuttx/arch/arm/src/lm/lm_ethernet.c
@@ -153,7 +153,7 @@
#define ETHBUF ((struct uip_eth_hdr *)priv->ld_dev.d_buf)
-#define LM32S_MAX_MDCCLK 2500000
+#define LM_MAX_MDCCLK 2500000
/****************************************************************************
* Private Types
@@ -1047,10 +1047,10 @@ static int lm_ifup(struct uip_driver_s *dev)
* div = (SYSCLK_FREQUENCY / 2 / MDCCLK_FREQUENCY) - 1
*
* Where the maximum value for MDCCLK_FREQUENCY is 2,500,000. We will
* add 1 to assure the max LM32S_MAX_MDCCLK is not exceeded.
*/
- div = SYSCLK_FREQUENCY / 2 / LM32S_MAX_MDCCLK;
+ div = SYSCLK_FREQUENCY / 2 / LM_MAX_MDCCLK;
lm_ethout(priv, LM_MAC_MDV_OFFSET, div);
nllvdbg("MDV: %08x\n", div);
@@ -1047,10 +1047,10 @@ static int lm_ifup(struct uip_driver_s *dev)
*
* Where the maximum value for MDCCLK_FREQUENCY is 2,500,000. We will
- * add 1 to assure the max LM32S_MAX_MDCCLK is not exceeded.
+ * add 1 to assure the max LM_MAX_MDCCLK is not exceeded.
*/